BluetoothDevice class

Represents a Bluetooth device with basic identifying information.

Constructors

BluetoothDevice({required String name, required String? address, required String connectionState})
BluetoothDevice.fromMap(Map<String, dynamic> map)
factory

Properties

address → String?
The device MAC address, if available.
final
connectionState → String
Connection state description (e.g., connected, disconnected).
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The device's human-readable name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited